aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/CodeGen/MachineFrameInfo.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2002-12-28 21:08:28 +0000
committerChris Lattner <sabre@nondot.org>2002-12-28 21:08:28 +0000
commitaa09b75d2257545c4583265c7ce10f2d0e3be72b (patch)
treed12fc1499a1212c30a05c0b33a6ab8e41c73a833 /include/llvm/CodeGen/MachineFrameInfo.h
parenteb24db9727a7babe863d5afe70c7bda3a460da18 (diff)
Rename FunctionFrameInfo to MachineFrameInfo
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@5201 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/CodeGen/MachineFrameInfo.h')
-rw-r--r--include/llvm/CodeGen/MachineFrameInfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/CodeGen/MachineFrameInfo.h b/include/llvm/CodeGen/MachineFrameInfo.h
index fc8394297d..6d640a6b5a 100644
--- a/include/llvm/CodeGen/MachineFrameInfo.h
+++ b/include/llvm/CodeGen/MachineFrameInfo.h
@@ -1,6 +1,6 @@
//===-- CodeGen/FunctionFrameInfo.h - Abstract Stack Frame Rep --*- C++ -*-===//
//
// The FunctionFrameInfo class represents an abstract stack frame until
// prolog/epilog code is inserted. This class is key to allowing stack frame
// representation optimizations, such as frame pointer elimination. It also
// allows more mundane (but still important) optimizations, such as reordering
@@ -31,7 +31,7 @@
#ifndef LLVM_CODEGEN_FUNCTIONFRAMEINFO_H
#define LLVM_CODEGEN_FUNCTIONFRAMEINFO_H
-class FunctionFrameInfo {
+class MachineFrameInfo {
// StackObject - Represent a single object allocated on the stack.
struct StackObject {
@@ -83,7 +83,7 @@ class FunctionFrameInfo {
///
unsigned MaxCallFrameSize;
public:
- FunctionFrameInfo() {
+ MachineFrameInfo() {
NumFixedObjects = StackSize = 0;
HasVarSizedObjects = false;
HasCalls = false;
@@ -181,7 +181,7 @@ public:
return Objects.size()-NumFixedObjects-1;
}
/// CreateVariableSizedObject - Notify the FunctionFrameInfo object that a
/// variable sized object has been created. This must be created whenever a
/// variable sized object is created, whether or not the index returned is
/// actually used.
@@ -1,6 +1,6 @@
-//===-- CodeGen/FunctionFrameInfo.h - Abstract Stack Frame Rep --*- C++ -*-===//
+//===-- CodeGen/MachineFrameInfo.h - Abstract Stack Frame Rep. --*- C++ -*-===//
//
@@ -1,6 +1,6 @@
//
-// The FunctionFrameInfo class represents an abstract stack frame until
+// The MachineFrameInfo class represents an abstract stack frame until
// prolog/epilog code is inserted. This class is key to allowing stack frame
// representation optimizations, such as frame pointer elimination. It also
@@ -181,7 +181,7 @@ public:
return Objects.size()-NumFixedObjects-1;
}
- /// CreateVariableSizedObject - Notify the FunctionFrameInfo object that a
+ /// CreateVariableSizedObject - Notify the MachineFrameInfo object that a
/// variable sized object has been created. This must be created whenever a
/// variable sized object is created, whether or not the index returned is